%define upstream_name Context-Preserve
%define upstream_version 0.03

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 4
License:    GPL or Artistic
Group:      Development/Perl
Summary:    Run code after a subroutine call, preserving the context the subroutine would have seen if it were the last statement in the caller
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Context/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Test::Exception)
BuildRequires: perl(Test::More)
BuildRequires: perl(base)
BuildRequires: perl(ok)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%{?perl_default_filter}

%description
Sometimes you need to call a function, get the results, act on the results,
then return the result of the function. This is painful because of
contexts; the original function can behave different if it's called in
void, scalar, or list context. You can ignore the various cases and just
pick one, but that's fragile. To do things right, you need to see which
case you're being called in, and then call the function in that context.
This results in 3 code paths, which is a pain to type in (and maintain).

This module automates the process. You provide a coderef that is the
"original function", and another coderef to run after the original runs.
You can modify the return value (aliased to @_) here, and do whatever else
you need to do. 'wantarray' is correct inside both coderefs; in "after",
though, the return value is ignored and the value 'wantarray' returns is
related to the context that the original function was called in.

%prep
%setup -q -n %{upstream_name}-%{upstream_version} 

%build
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc CONTRIBUTING Changes INSTALL LICENCE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Sun Mar 20 2022 umeabot <umeabot> 0.30.0-4.mga9
+ Revision: 1808579
- Mageia 9 Mass Rebuild

* Wed Feb 12 2020 umeabot <umeabot> 0.30.0-3.mga8
+ Revision: 1503597
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0.30.0-2.mga7
+ Revision: 1282477
- Mageia 7 Mass Rebuild

* Mon Nov 06 2017 tv <tv> 0.30.0-1.mga7
+ Revision: 1176175
- update to 0.03

* Mon Oct 02 2017 tv <tv> 0.20.0-2.mga7
+ Revision: 1163528
- rebuild with fixed rpm for missing autodeps

* Tue Sep 19 2017 tv <tv> 0.20.0-1.mga7
+ Revision: 1155607
- update to 0.02

* Sat Jun 18 2016 pterjan <pterjan> 0.10.0-3.mga6
+ Revision: 1024326
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.10.0-2.mga6
+ Revision: 947105
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.01-7.mga5
+ Revision: 747026
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 0.01-6.mga5
+ Revision: 732959
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.01-5.mga5
+ Revision: 684007
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.01-4.mga4
+ Revision: 510306
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.01-3.mga3
+ Revision: 364734
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 21 2011 jquelin <jquelin> 0.01-2.mga1
+ Revision: 28436
- mageia rebuild
- cleaning spec file
- imported package perl-Context-Preserve

